# French map, proportion infected by region

 

workdir <- "Samples"
setwd(workdir)

# Prepare geographic data  ---------------------------

# 1. Polygon data
# shapefile of regions
reg<-readShapePoly("France_regions_new.shp")
plot(reg)
names(reg)
# Define the coordinates system/projection : Lambert93 = code epsg 2154
proj4string(reg) <- CRS("+init=epsg:2154")
list.reg<-as.character(unique(reg@data$CODE_REG))
# Pre-treatment: the shapefile has to be converted to a dataframe for use in ggplot2
reg.f<-fortify(reg)
# add the data in reg to reg.f (here : only region codes and names)
reg$id<-row.names(reg)
reg$CODE_REG<-as.character(reg$CODE_REG)
reg.f<-left_join(reg.f,reg@data)
head(reg.f,2)

setwd('..')
# 2. Point data
# Lat/long coordinates of cities
# toy example : I take the centers of regions
myCoords<-data.frame(coordinates(reg))
names(myCoords)<-c("long","lat")
myCoords$cities<-LETTERS[1:13]


# Prepare epi data  ---------------------------


codes.region<-c(11,24,27,28,
                32,44,52,53,
                75,76,84,93,94,1,2,3,4,5,6,7,8)
names.region<-c("IDF","CVL","BFC","NOR",
                "HDF","GES","PDL","BRE",
                "NAQ","OCC","ARA","PAC","COR","GUA","MAR","GUY","RUN","SPM","MAY","SXB","SXM")
list.region.df.map<-data.frame(code=codes.region,name=names.region)



W1 = which(data.infected$date ==DATE)
immune = data.infected[W1,] 
list_reg = list.region.df.map$code[match(immune$region, list.region.df.map$name)]

dataset.regions<-data.frame(CODE_REG=as.character(list_reg),
                            Proportion=immune$infected.mean)

reg.f.join<-left_join(reg.f,dataset.regions,by="CODE_REG") 

map<-ggplot()  +  
  geom_polygon(data=reg.f.join, aes(long,lat,group=group,fill=Proportion),colour=NA)+
  coord_equal()

map = map + 
  theme_classic() +
  theme(axis.title.y = element_blank(),
        axis.title.x = element_blank(),
        axis.text.x=element_blank(),
        axis.text.y=element_blank(),
        axis.ticks=element_blank(),
        axis.line=element_blank())+
  scale_fill_gradientn(colours=c("lightblue1","darkorchid4"),values=rescale(c(0,100)),
                       na.value='transparent',limits=c(0,42),name="Proportion (%)")
print(map)

